@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-//$Id: DatatypeFactory.java 759805 2009-03-30 00:31:41Z mrglavas $
+//$Id: DatatypeFactory.java 884950 2009-11-27 18:46:18Z mrglavas $
 
 package javax.xml.datatype;
 
@@ -52,7 +52,7 @@ import java.util.GregorianCalendar;
  * 
  * @author <a href="mailto:Joseph.Fialli@Sun.COM">Joseph Fialli</a>
  * @author <a href="mailto:Jeff.Suttor@Sun.com">Jeff Suttor</a>
- * @version $Revision: 759805 $, $Date: 2009-03-30 02:31:41 +0200 (Mo, 30. Mär 2009) $
+ * @version $Revision: 884950 $, $Date: 2009-11-27 19:46:18 +0100 (Fr, 27. Nov 2009) $
  * @since 1.5
  */
 public abstract class DatatypeFactory {
@@ -69,7 +69,7 @@ public abstract class DatatypeFactory {
      * 
      * <p>Default value is <code>org.apache.xerces.jaxp.datatype.DatatypeFactoryImpl</code>.</p>
      */
-    public static final String DATATYPEFACTORY_IMPLEMENTATION_CLASS = "org.apache.xerces.jaxp.datatype.DatatypeFactoryImpl";
+    public static final String DATATYPEFACTORY_IMPLEMENTATION_CLASS = new String("org.apache.xerces.jaxp.datatype.DatatypeFactoryImpl");
 
     /**
      * <p>Protected constructor to prevent instantiation outside of package.</p>
@@ -91,7 +91,6 @@ public abstract class DatatypeFactory {
      */
     public static DatatypeFactory newInstance()
         throws DatatypeConfigurationException {
-
         try {
             return (DatatypeFactory) FactoryFinder.find(
                     /* The default property name according to the JAXP spec */
@@ -103,6 +102,28 @@ public abstract class DatatypeFactory {
             throw new DatatypeConfigurationException(e.getMessage(), e.getException());
         }
     }
+    
+    /**
+     * @return New instance of a <code>DocumentBuilderFactory</code>
+     *
+     * @throws DatatypeConfigurationException If the implementation is not
+     *   available or cannot be instantiated.
+     */
+    public static DatatypeFactory newInstance(String factoryClassName,
+            ClassLoader classLoader) throws DatatypeConfigurationException {
+        if (factoryClassName == null) {
+            throw new DatatypeConfigurationException("factoryClassName cannot be null.");
+        }
+        if (classLoader == null) {
+            classLoader = SecuritySupport.getContextClassLoader();
+        }
+        try {
+            return (DatatypeFactory) FactoryFinder.newInstance(factoryClassName, classLoader);
+        }
+        catch (FactoryFinder.ConfigurationError e) {
+            throw new DatatypeConfigurationException(e.getMessage(), e.getException());
+        }
+    }
 
     /**
      * <p>Obtain a new instance of a <code>Duration</code>
