@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-//$Id: Duration.java 759827 2009-03-30 01:26:10Z mrglavas $
+//$Id: Duration.java 759828 2009-03-30 01:26:29Z mrglavas $
 
 package javax.xml.datatype;
 
@@ -87,7 +87,7 @@ import javax.xml.namespace.QName;
  * @author <a href="mailto:Joseph.Fialli@Sun.COM">Joseph Fialli</a>
  * @author <a href="mailto:Kohsuke.Kawaguchi@Sun.com">Kohsuke Kawaguchi</a>
  * @author <a href="mailto:Jeff.Suttor@Sun.com">Jeff Suttor</a>
- * @version $Revision: 759827 $, $Date: 2009-03-30 03:26:10 +0200 (Mo, 30. Mär 2009) $    
+ * @version $Revision: 759828 $, $Date: 2009-03-30 03:26:29 +0200 (Mo, 30. Mär 2009) $    
  * @see XMLGregorianCalendar#add(Duration)
  * @since 1.5
  */
@@ -845,14 +845,13 @@ public abstract class Duration {
      *      <code>true</code> if this duration is the same length as
      *         <code>duration</code>.
      *      <code>false</code> if <code>duration</code> is not a
-     *         <code>Duration</code> object
+     *         <code>Duration</code> object, is <code>null</code>,
      *         or its length is different from this duration.
      * 
      * @throws UnsupportedOperationException If the underlying implementation
      *   cannot reasonably process the request, e.g. W3C XML Schema allows for
      *   arbitrarily large/small/precise values, the request may be beyond the
      *   implementations capability.
-     * @throws NullPointerException if parameter is null.
      *
      * @see #compare(Duration duration)
      */
@@ -860,9 +859,6 @@ public abstract class Duration {
         if (duration == this) {
             return true;
         }
-        if (duration == null) {
-            throw new NullPointerException();
-        }
         if (duration instanceof Duration) {
             return compare((Duration) duration) == DatatypeConstants.EQUAL;
         }
