@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-// $Id: XMLGregorianCalendar.java 759820 2009-03-30 01:14:57Z mrglavas $
+// $Id: XMLGregorianCalendar.java 759822 2009-03-30 01:15:11Z mrglavas $
 
 package javax.xml.datatype;
 
@@ -169,7 +169,7 @@ import java.util.GregorianCalendar;
  * @author <a href="mailto:Joseph.Fialli@Sun.com">Joseph Fialli</a>
  * @author <a href="mailto:Kohsuke.Kawaguchi@Sun.com">Kohsuke Kawaguchi</a>
  * @author <a href="mailto:Jeff.Suttor@Sun.com">Jeff Suttor</a>
- * @version $Revision: 759820 $, $Date: 2009-03-30 03:14:57 +0200 (Mo, 30. Mär 2009) $    
+ * @version $Revision: 759822 $, $Date: 2009-03-30 03:15:11 +0200 (Mo, 30. Mär 2009) $    
  * @see Duration
  * @see DatatypeFactory
  * @since 1.5
@@ -658,16 +658,11 @@ public abstract class XMLGregorianCalendar
      *
      * @return <code>true</code> when <code>obj</code> is an instance of <code>XMLGregorianCalendar</code>
      *   and  {@link #compare(XMLGregorianCalendar obj)} returns {@link DatatypeConstants#EQUAL}, otherwise <code>false</code>.
-     * 
-     * @throws NullPointerException If <code>obj</code> is <code>null</code>.
      */
     public boolean equals(Object obj) {
         if (obj == this) {
             return true;
         }
-        if (obj == null) {
-            throw new NullPointerException("Cannot test null for equality with this XMLGregorianCalendar");
-        }
         if (obj instanceof XMLGregorianCalendar) {
             return compare((XMLGregorianCalendar) obj) == DatatypeConstants.EQUAL;
         }
