@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-// $Id: DocumentBuilderFactory.java 569979 2007-08-27 03:57:11Z mrglavas $
+// $Id: DocumentBuilderFactory.java 884950 2009-11-27 18:46:18Z mrglavas $
 
 package javax.xml.parsers;
 
@@ -26,7 +26,7 @@ import javax.xml.validation.Schema;
  * parser that produces DOM object trees from XML documents.
  *
  * @author <a href="Jeff.Suttor@Sun.com">Jeff Suttor</a>
- * @version $Revision: 569979 $, $Date: 2007-08-27 05:57:11 +0200 (Mo, 27. Aug 2007) $
+ * @version $Revision: 884950 $, $Date: 2009-11-27 19:46:18 +0100 (Fr, 27. Nov 2009) $
  */
 
 public abstract class DocumentBuilderFactory {
@@ -105,11 +105,32 @@ public abstract class DocumentBuilderFactory {
                 "javax.xml.parsers.DocumentBuilderFactory",
                 /* The fallback implementation class name */
                 "org.apache.xerces.jaxp.DocumentBuilderFactoryImpl");
-        } catch (FactoryFinder.ConfigurationError e) {
-            throw new FactoryConfigurationError(e.getException(),
-                                                e.getMessage());
+        } 
+        catch (FactoryFinder.ConfigurationError e) {
+            throw new FactoryConfigurationError(e.getException(), e.getMessage());
+        }
+    }
+    
+    /**
+     * @return New instance of a <code>DocumentBuilderFactory</code>
+     *
+     * @exception FactoryConfigurationError if the implementation is not
+     * available or cannot be instantiated.
+     */
+    public static DocumentBuilderFactory newInstance(String factoryClassName,
+            ClassLoader classLoader) {
+        if (factoryClassName == null) {
+            throw new FactoryConfigurationError("factoryClassName cannot be null.");
+        }
+        if (classLoader == null) {
+            classLoader = SecuritySupport.getContextClassLoader();
+        }
+        try {
+            return (DocumentBuilderFactory) FactoryFinder.newInstance(factoryClassName, classLoader, false);
+        }
+        catch (FactoryFinder.ConfigurationError e) {
+            throw new FactoryConfigurationError(e.getException(), e.getMessage());
         }
-
     }
 
     /**
