@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-// $Id: SchemaFactory.java 569992 2007-08-27 04:18:22Z mrglavas $
+// $Id: SchemaFactory.java 884952 2009-11-27 18:55:08Z mrglavas $
 
 package javax.xml.validation;
 
@@ -98,7 +98,7 @@ import org.xml.sax.SAXNotSupportedException;
  * </table>
  * 
  * @author  <a href="mailto:Kohsuke.Kawaguchi@Sun.com">Kohsuke Kawaguchi</a>
- * @version $Revision: 569992 $, $Date: 2007-08-27 06:18:22 +0200 (Mo, 27. Aug 2007) $
+ * @version $Revision: 884952 $, $Date: 2009-11-27 19:55:08 +0100 (Fr, 27. Nov 2009) $
  * @since 1.5
  */
 public abstract class SchemaFactory {
@@ -196,6 +196,33 @@ public abstract class SchemaFactory {
         return f;
     }
     
+    /**
+     * @return New instance of a <code>SchemaFactory</code>
+     * 
+     * @throws IllegalArgumentException
+     *      If no implementation of the schema language is available.
+     * 
+     * @throws NullPointerException
+     *      If the <tt>schemLanguage</tt> parameter is null.
+     */
+    public static SchemaFactory newInstance(String schemaLanguage,
+            String factoryClassName, ClassLoader classLoader) {
+        if (schemaLanguage == null) {      
+            throw new NullPointerException();
+        }
+        if (factoryClassName == null) {
+            throw new IllegalArgumentException("factoryClassName cannot be null.");
+        }
+        if (classLoader == null) {
+            classLoader = SecuritySupport.getContextClassLoader();
+        }
+        SchemaFactory f = new SchemaFactoryFinder(classLoader).createInstance(factoryClassName);
+        if (f == null || !f.isSchemaLanguageSupported(schemaLanguage)) {
+            throw new IllegalArgumentException(schemaLanguage);
+        }
+        return f;
+    }
+    
 	/**
 	 * <p>Is specified schema supported by this <code>SchemaFactory</code>?</p>
 	 * 
@@ -573,8 +600,10 @@ public abstract class SchemaFactory {
      * 
      * @param schemas
      *      inputs to be parsed. {@link SchemaFactory} is required
-     *      to recognize {@link javax.xml.transform.sax.SAXSource},
-     *      {@link StreamSource}, and {@link javax.xml.transform.dom.DOMSource}.
+     *      to recognize {@link StreamSource}, 
+     *      {@link javax.xml.transform.sax.SAXSource},
+     *      {@link javax.xml.transform.dom.DOMSource}
+     *      and {@link javax.xml.transform.stax.StAXSource}.
      * 
      * @return
      *      Always return a non-null valid {@link Schema} object.
