@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-// $Id: SchemaFactoryFinder.java 727365 2008-12-17 12:59:01Z mrglavas $
+// $Id: SchemaFactoryFinder.java 727367 2008-12-17 13:05:26Z mrglavas $
 
 package javax.xml.validation;
 
@@ -36,10 +36,14 @@ import javax.xml.XMLConstants;
  * Implementation of {@link SchemaFactory#newInstance(String)}.
  * 
  * @author <a href="Kohsuke.Kawaguchi@Sun.com">Kohsuke Kawaguchi</a>
- * @version $Revision: 727365 $, $Date: 2008-12-17 13:59:01 +0100 (Mi, 17. Dez 2008) $
+ * @version $Revision: 727367 $, $Date: 2008-12-17 14:05:26 +0100 (Mi, 17. Dez 2008) $
  * @since 1.5
  */
 final class SchemaFactoryFinder  {
+    
+    /** XML Schema language identifiers. */
+    private static final String W3C_XML_SCHEMA10_NS_URI = "http://www.w3.org/XML/XMLSchema/v1.0";
+    private static final String W3C_XML_SCHEMA11_NS_URI = "http://www.w3.org/XML/XMLSchema/v1.1";  
 
     /** debug support code. */
     private static boolean debug = false;
@@ -269,11 +273,15 @@ final class SchemaFactoryFinder  {
             }
         }
         
-        // platform default
-        if (schemaLanguage.equals(XMLConstants.W3C_XML_SCHEMA_NS_URI)) {
-            if (debug) debugPrintln("attempting to use the platform default XML Schema validator");
+        // platform defaults
+        if (schemaLanguage.equals(XMLConstants.W3C_XML_SCHEMA_NS_URI) || schemaLanguage.equals(W3C_XML_SCHEMA10_NS_URI)) {
+            if (debug) debugPrintln("attempting to use the platform default XML Schema 1.0 validator");
             return createInstance("org.apache.xerces.jaxp.validation.XMLSchemaFactory");
         }
+        else if (schemaLanguage.equals(W3C_XML_SCHEMA11_NS_URI)) {
+            if (debug) debugPrintln("attempting to use the platform default XML Schema 1.1 validator");
+            return createInstance("org.apache.xerces.jaxp.validation.XMLSchema11Factory");
+        }
         
         if (debug) debugPrintln("all things were tried, but none was found. bailing out.");
         return null;
@@ -288,7 +296,7 @@ final class SchemaFactoryFinder  {
      * @return null
      *      if it fails. Error messages will be printed by this method. 
      */
-    private SchemaFactory createInstance( String className ) {
+    SchemaFactory createInstance( String className ) {
         try {
             if (debug) debugPrintln("instanciating "+className);
             Class clazz;
